@@ -9,7 +9,7 @@ class DBConn:
         """ 初始化连接池
                 如果是sqlite，db这个参数是要显示给入的
                 如果是oracle，db给入的是sid或是servername都是可以的 """
-        self.close()
+        self.dbpool = None
         self.dbtype = dbtype
         config = {
             'host':host,
@@ -144,6 +144,8 @@ class DBConn:
             self.dbpool.close()
         except:
             pass
+        finally:
+            self.dbpool = None
     
     def __del__(self):
         self.close()
